/* 
 * Copyright (c) 2001 by Dov Grobgeld <dov@imagic.weizmann.ac.il>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_IMAGE_VIEWER_H__
#define __GTK_IMAGE_VIEWER_H__

#include <gdk/gdk.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkdrawingarea.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

#ifdef __cplusplus
extern "C" {
#endif

#define GTK_IMAGE_VIEWER(obj)          GTK_CHECK_CAST (obj, gtk_image_viewer_get_type (), GtkImageViewer)
#define GTK_IMAGE_VIEWER_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gtk_image_viewer_get_type (), GtkImageViewerClass)
#define GTK_ISIMAGE_VIEWER(obj)       GTK_CHECK_TYPE (obj, gtk_image_viewer_get_type ())


typedef struct _GtkImageViewer        GtkImageViewer;
typedef struct _GtkImageViewerClass   GtkImageViewerClass;

struct _GtkImageViewer
{
  GtkWidget widget;
  GdkPixbuf *image;
  double current_scale_x, current_scale_y, current_x0, current_y0;
  gint canvas_width, canvas_height;
  gboolean do_use_transfer_map;
  guint8 *transfer_map[3];

  /* Motion related functions */
  gboolean is_mouse_button2_pressed;
  gint last_pan_anchor_x, last_pan_anchor_y;
  gint last_x, last_y;
  gint button;
  
  /* Settings */
  GdkInterpType interp_type;

  /* Configuration */
  gdouble min_zoom;
  gdouble max_zoom;
};

struct _GtkImageViewerClass
{
  GtkWidgetClass parent_class;

  void (*view_changed) (GtkImageViewer *image_viewer);
};

GtkWidget*     gtk_image_viewer_new          (GdkPixbuf *_img);
GtkWidget*     gtk_image_viewer_new_from_file(const char *filename);
guint          gtk_image_viewer_get_type     (void);
guint	       gtk_image_viewer_set_image    (GtkImageViewer *widget,
					      GdkPixbuf *_img);
guint	       gtk_image_viewer_set_file     (GtkImageViewer *widget,
					      char *filename);
GdkPixbuf*     gtk_image_viewer_get_image    (GtkImageViewer *widget);
gboolean       gtk_image_viewer_get_is_panning(GtkImageViewer *widget);
guint          gtk_image_viewer_get_canvas_width(GtkImageViewer *widget);
guint          gtk_image_viewer_get_canvas_height(GtkImageViewer *widget);
void           gtk_image_viewer_get_scale    (GtkImageViewer *widget,
					      /* output */
					      double *scale_x,
					      double *scale_y
					      );
void           gtk_image_viewer_get_transform(GtkImageViewer *widget,
					      /* output */
					      double *x,
					      double *y,
					      double *scale_x,
					      double *scale_y);
void           gtk_image_viewer_set_transform(GtkImageViewer *widget,
					      double x,
					      double y,
					      double scale_x,
					      double scale_y);
void           gtk_image_viewer_img_coord_to_canv_coord(
                                              GtkImageViewer *image_viewer,
				              double imgx,
					      double imgy,
					      /* output */
					      double *cx,
					      double *cy);
void           gtk_image_viewer_canv_coord_to_img_coord(
                                              GtkImageViewer *image_viewer,
					      double cx, double cy,
					      /* output */
					      double *imgx, double *imgy);

void           gtk_image_viewer_set_transfer_map(GtkImageViewer *widget,
						 guint8 *rmap,
						 guint8 *gmap,
						 guint8 *bmap);
gint           gtk_image_viewer_redraw(GtkWidget *widget);
gint           gtk_image_viewer_zoom_around_fixed_point(
                                       GtkImageViewer *image_viewer,
				       double new_scale_x,
				       double new_scale_y,
				       double old_x,
				       double old_y,
				       double new_x,
				       double new_y);
void           gtk_image_viewer_expose_area(GtkImageViewer *image_viewer,
					    int x0, int y0,
					    int w, int h);

#ifdef __cplusplus
}
#endif
    

#endif
